#include <QApplication>
#include <QDebug>
#include <QSpinBox>
#include <QPushButton>
#include <QThread>
#include <QFormLayout>
#include <QLabel>
#include <QClipboard>
#include <QPlainTextEdit>

static QString description()
{
    QString t = QT_VERSION_STR;
#if QT_VERSION >= 0x050000
    t += QLatin1Char(' ') + QGuiApplication::platformName();
#endif
    return t;
}

class Widget : public  QWidget {
    Q_OBJECT
  public:
    Widget();

public slots:
    void repeatedCopy();
private:
	QPlainTextEdit *plainEdit;
    QSpinBox *m_repeats;
    QSpinBox *m_interval;
};

Widget::Widget()
{
    QFormLayout *fl = new QFormLayout(this);
    m_repeats = new QSpinBox;
    m_repeats->setRange(1, 1000);
    m_repeats->setValue(50);
    fl->addRow("Repeats", m_repeats);
    m_interval = new QSpinBox;
    m_interval->setRange(0, 100);
    m_interval->setValue(1);
    fl->addRow("Interval",m_interval);
	plainEdit = new QPlainTextEdit;
	fl->addRow("Text to copy", plainEdit);
    QPushButton *b = new QPushButton("Copy");
    connect(b, &QAbstractButton::clicked, this, &Widget::repeatedCopy);
    fl->addRow(b);
    setMinimumWidth(200);
}

void Widget::repeatedCopy()
{
    qDebug(">%s", __FUNCTION__);
    const int r = m_repeats->value();
    const int iv = m_interval->value();
    QClipboard *cb = QGuiApplication::clipboard();
    for (int i = 0; i < r; ++i) {
		cb->setText(")");
		cb->setText(plainEdit->toPlainText());
        if (iv)
            QThread::msleep(iv);
    }
    qDebug("<%s", __FUNCTION__);
}

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    QStringList args = app.arguments();
    args.pop_front();

    QString t = description();
    qDebug() << t << args;
    Widget w;
    w.setWindowTitle(t);
    w.show();
    return app.exec();
}

#include "main.moc"
